@@ -17,31 +17,28 @@
  * under the License.
  */
 
-import { AggConfig } from '../../vis/agg_config';
 import { AggType } from '../../agg_types/agg_type';
+import { i18n } from '@kbn/i18n';
 
-export function PointSeriesFakeXAxisProvider() {
+const allAgg = new AggType({
+  name: 'all',
+  title: i18n.translate('common.ui.aggResponse.allDocsTitle', {
+    defaultMessage: 'All docs'
+  }),
+  ordered: false,
+  hasNoDsl: true
+});
 
-  const allAgg = new AggType({
-    name: 'all',
-    title: 'All docs',
-    ordered: false,
-    hasNoDsl: true
-  });
+export function makeFakeXAspect() {
+  const fake = {
+    makeLabel: () => 'all',
+    fieldFormatter: () => '',
+    type: allAgg
+  };
 
-  return function makeFakeXAxis(vis) {
-    const fake = new AggConfig(vis, {
-      type: allAgg,
-      schema: vis.type.schemas.all.byName.segment
-    });
-
-    return {
-      i: -1,
-      agg: fake,
-      col: {
-        aggConfig: fake,
-        label: fake.makeLabel()
-      }
-    };
+  return {
+    i: -1,
+    aggConfig: fake,
+    title: fake.makeLabel(),
   };
 }
