@@ -20,7 +20,6 @@
 import 'angular';
 import 'angular-recursion';
 import '../paginated_table';
-import './agg_table.less';
 import _ from 'lodash';
 import { uiModules } from '../modules';
 import aggTableTemplate from './agg_table.html';
@@ -102,10 +101,10 @@ uiModules
             return;
           }
 
-          self.csv.filename = ($scope.exportTitle || table.title() || 'table') + '.csv';
+          self.csv.filename = ($scope.exportTitle || table.title || 'table') + '.csv';
           $scope.rows = table.rows;
           $scope.formattedColumns = table.columns.map(function (col, i) {
-            const agg = $scope.table.aggConfig(col);
+            const agg = col.aggConfig;
             const field = agg.getField();
             const formattedColumn = {
               title: col.title,
