@@ -17,13 +17,13 @@
  * under the License.
  */
 
-import { buildRangeFilter } from '../../../filter_manager/lib/range';
+import { buildRangeFilter } from '@kbn/es-query';
 
 export function createFilterRange(aggConfig, key) {
   return buildRangeFilter(
     aggConfig.params.field,
     key,
-    aggConfig._indexPattern,
+    aggConfig.getIndexPattern(),
     aggConfig.fieldFormatter()(key)
   );
 }
