@@ -22,12 +22,17 @@ import angular from 'angular';
 
 import { BucketAggType } from './_bucket_agg_type';
 import { createFilterFilters } from './create_filter/filters';
-import { decorateQuery, luceneStringToDsl } from '../../courier';
+import { decorateQuery, luceneStringToDsl } from '@kbn/es-query';
 import filtersTemplate from '../controls/filters.html';
+import { i18n } from '@kbn/i18n';
+
+import chrome from 'ui/chrome';
 
 export const filtersBucketAgg = new BucketAggType({
   name: 'filters',
-  title: 'Filters',
+  title: i18n.translate('common.ui.aggTypes.buckets.filtersTitle', {
+    defaultMessage: 'Filters',
+  }),
   createFilter: createFilterFilters,
   customLabels: false,
   params: [
@@ -53,7 +58,7 @@ export const filtersBucketAgg = new BucketAggType({
             return;
           }
 
-          decorateQuery(query);
+          decorateQuery(query, chrome.getUiSettingsClient());
 
           const matchAllLabel = (filter.input.query === '' && _.has(query, 'match_all')) ? '*' : '';
           const label = filter.label || matchAllLabel || _.get(query, 'query_string.query') || angular.toJson(query);
