@@ -20,11 +20,18 @@
 import { MetricAggType } from './metric_agg_type';
 import { makeNestedLabel } from './lib/make_nested_label';
 import { siblingPipelineAggHelper } from './lib/sibling_pipeline_agg_helper';
+import { i18n } from '@kbn/i18n';
+
+const overallMaxLabel = i18n.translate('common.ui.aggTypes.metrics.overallMaxLabel', {
+  defaultMessage: 'overall max'
+});
 
 export const bucketMaxMetricAgg = new MetricAggType({
   name: 'max_bucket',
-  title: 'Max Bucket',
-  makeLabel: agg => makeNestedLabel(agg, 'overall max'),
+  title: i18n.translate('common.ui.aggTypes.metrics.maxBucketTitle', {
+    defaultMessage: 'Max Bucket'
+  }),
+  makeLabel: agg => makeNestedLabel(agg, overallMaxLabel),
   subtype: siblingPipelineAggHelper.subtype,
   params: [
     ...siblingPipelineAggHelper.params()
