@@ -20,12 +20,19 @@
 import { MetricAggType } from './metric_agg_type';
 import { parentPipelineAggHelper } from './lib/parent_pipeline_agg_helper';
 import { makeNestedLabel } from './lib/make_nested_label';
+import { i18n } from '@kbn/i18n';
+
+const derivativeLabel = i18n.translate('common.ui.aggTypes.metrics.derivativeLabel', {
+  defaultMessage: 'derivative'
+});
 
 export const derivativeMetricAgg = new MetricAggType({
   name: 'derivative',
-  title: 'Derivative',
+  title: i18n.translate('common.ui.aggTypes.metrics.derivativeTitle', {
+    defaultMessage: 'Derivative'
+  }),
   subtype: parentPipelineAggHelper.subtype,
-  makeLabel: agg => makeNestedLabel(agg, 'derivative'),
+  makeLabel: agg => makeNestedLabel(agg, derivativeLabel),
   params: [
     ...parentPipelineAggHelper.params()
   ],
