@@ -20,12 +20,19 @@
 import { MetricAggType } from './metric_agg_type';
 import { parentPipelineAggHelper } from './lib/parent_pipeline_agg_helper';
 import { makeNestedLabel } from './lib/make_nested_label';
+import { i18n } from '@kbn/i18n';
+
+const movingAvgLabel = i18n.translate('common.ui.aggTypes.metrics.movingAvgLabel', {
+  defaultMessage: 'moving avg'
+});
 
 export const movingAvgMetricAgg = new MetricAggType({
   name: 'moving_avg',
-  title: 'Moving Avg',
+  title: i18n.translate('common.ui.aggTypes.metrics.movingAvgTitle', {
+    defaultMessage: 'Moving Avg'
+  }),
   subtype: parentPipelineAggHelper.subtype,
-  makeLabel: agg => makeNestedLabel(agg, 'moving avg'),
+  makeLabel: agg => makeNestedLabel(agg, movingAvgLabel),
   params: [
     ...parentPipelineAggHelper.params()
   ],
