@@ -17,18 +17,18 @@
  * under the License.
  */
 
-import { metadata } from '../../metadata';
-import { Notifier } from '../../notify';
-import { UiSettingsClient } from '../../../ui_settings/public/ui_settings_client';
+let newPlatformUiSettingsClient;
+
+export function __newPlatformInit__(instance) {
+  if (newPlatformUiSettingsClient) {
+    throw new Error('ui/chrome/api/ui_settings already initialized');
+  }
+
+  newPlatformUiSettingsClient = instance;
+}
 
 export function initUiSettingsApi(chrome) {
-  const uiSettings = new UiSettingsClient({
-    defaults: metadata.uiSettings.defaults,
-    initialSettings: metadata.uiSettings.user,
-    notify: new Notifier({ location: 'Config' })
-  });
-
   chrome.getUiSettingsClient = function () {
-    return uiSettings;
+    return newPlatformUiSettingsClient;
   };
 }
