@@ -71,9 +71,9 @@
 
 import _ from 'lodash';
 import angular from 'angular';
+import { BuildESQueryProvider } from '@kbn/es-query';
 
 import '../../promises';
-
 import { NormalizeSortRequestProvider } from './_normalize_sort_request';
 import { SearchRequestProvider } from '../fetch/request';
 import { SegmentedSearchRequestProvider } from '../fetch/request/segmented_search_request';
@@ -81,8 +81,8 @@ import { SegmentedSearchRequestProvider } from '../fetch/request/segmented_searc
 import { searchRequestQueue } from '../search_request_queue';
 import { FetchSoonProvider } from '../fetch';
 import { FieldWildcardProvider } from '../../field_wildcard';
-import { getHighlightRequest } from '../../../../core_plugins/kibana/common/highlight';
-import { BuildESQueryProvider } from './build_query';
+import { getHighlightRequest } from '../../../../legacy/core_plugins/kibana/common/highlight';
+import { KbnError, OutdatedKuerySyntaxError } from '../../errors';
 
 const FIELDS = [
   'type',
@@ -130,6 +130,7 @@ export function SearchSourceProvider(Promise, Private, config) {
     constructor(initialFields) {
       this._id = _.uniqueId('data_source');
 
+      this._searchStrategyId = undefined;
       this._fields = parseInitialFields(initialFields);
       this._parent = undefined;
 
@@ -164,6 +165,14 @@ export function SearchSourceProvider(Promise, Private, config) {
      * PUBLIC API
      *****/
 
+    setPreferredSearchStrategyId(searchStrategyId) {
+      this._searchStrategyId = searchStrategyId;
+    }
+
+    getPreferredSearchStrategyId() {
+      return this._searchStrategyId;
+    }
+
     setFields(newFields) {
       this._fields = newFields;
       return this;
@@ -601,7 +610,14 @@ export function SearchSourceProvider(Promise, Private, config) {
             _.set(flatData.body, '_source.includes', remainingFields);
           }
 
-          flatData.body.query = buildESQuery(flatData.index, flatData.query, flatData.filters);
+          try {
+            flatData.body.query = buildESQuery(flatData.index, flatData.query, flatData.filters);
+          } catch (e) {
+            if (e.message === 'OutdatedKuerySyntaxError') {
+              throw new OutdatedKuerySyntaxError();
+            }
+            throw new KbnError(e.message, KbnError);
+          }
 
           if (flatData.highlightAll != null) {
             if (flatData.highlightAll && flatData.body.query) {
