@@ -1,3 +1,22 @@
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 /**
  * @name Events
  *
@@ -5,13 +24,14 @@
  */
 
 import _ from 'lodash';
-import Notifier from 'ui/notify/notifier';
-import SimpleEmitter from 'ui/utils/simple_emitter';
+import { fatalError } from './notify';
+import { SimpleEmitter } from './utils/simple_emitter';
+import { createLegacyClass } from './utils/legacy_class';
 
-export default function EventsProvider(Private, Promise) {
-  const notify = new Notifier({ location: 'EventEmitter' });
+const location = 'EventEmitter';
 
-  _.class(Events).inherits(SimpleEmitter);
+export function EventsProvider(Private, Promise) {
+  createLegacyClass(Events).inherits(SimpleEmitter);
   function Events() {
     Events.Super.call(this);
     this._listeners = {};
@@ -25,7 +45,7 @@ export default function EventsProvider(Private, Promise) {
    * @return {Events} - this, for chaining
    */
   Events.prototype.on = function (name, handler) {
-    if (!_.isArray(this._listeners[name])) {
+    if (!Array.isArray(this._listeners[name])) {
       this._listeners[name] = [];
     }
 
@@ -40,7 +60,7 @@ export default function EventsProvider(Private, Promise) {
         rebuildDefer();
 
         // we ignore the completion of handlers, just watch for unhandled errors
-        Promise.resolve(handler.apply(handler, args)).catch(notify.fatal);
+        Promise.resolve(handler.apply(handler, args)).catch(error => fatalError(error, location));
       });
     }());
 
@@ -90,6 +110,9 @@ export default function EventsProvider(Private, Promise) {
 
     return Promise.map(self._listeners[name], function (listener) {
       return self._emitChain = self._emitChain.then(function () {
+        // Double check that off wasn't called after an emit, but before this is fired.
+        if (!self._listeners[name] || self._listeners[name].indexOf(listener) < 0) return;
+
         listener.defer.resolve(args);
         return listener.resolved;
       });
@@ -107,4 +130,4 @@ export default function EventsProvider(Private, Promise) {
   };
 
   return Events;
-};
+}
