@@ -17,11 +17,13 @@
  * under the License.
  */
 
+import { i18n } from '@kbn/i18n';
+
 export const getDefaultFormat = (Format) => {
   class DefaultFormat extends Format {
     static id = '';
     static resolvedTitle = Format.title;
-    static title = '- Default -';
+    static title = i18n.translate('common.ui.fieldEditor.defaultFormatDropDown', { defaultMessage: '- Default -' });
   }
 
   return DefaultFormat;
