@@ -17,7 +17,6 @@
  * under the License.
  */
 
-import React, { Fragment } from 'react';
 import _ from 'lodash';
 import { SavedObjectNotFound, DuplicateField, IndexPatternMissingIndices } from '../errors';
 import angular from 'angular';
@@ -35,6 +34,7 @@ import { IndexPatternsPatternCacheProvider } from './_pattern_cache';
 import { FieldsFetcherProvider } from './fields_fetcher_provider';
 import { IsUserAwareOfUnsupportedTimePatternProvider } from './unsupported_time_patterns';
 import { SavedObjectsClientProvider, findObjectByTitle } from '../saved_objects';
+import { i18n } from '@kbn/i18n';
 
 export function getRoutes() {
   return {
@@ -79,7 +79,9 @@ export function IndexPatternProvider(Private, config, Promise, confirmModalPromi
       _deserialize(map = '{}') {
         return _.mapValues(angular.fromJson(map), deserializeFieldFormatMap);
       }
-    }
+    },
+    type: 'keyword',
+    typeMeta: 'json',
   });
 
   function serializeFieldFormatMap(flat, format, field) {
@@ -118,14 +120,21 @@ export function IndexPatternProvider(Private, config, Promise, confirmModalPromi
 
     if (indexPattern.isUnsupportedTimePattern()) {
       if (!isUserAwareOfUnsupportedTimePattern(indexPattern)) {
+        const warningTitle = i18n.translate('common.ui.indexPattern.warningTitle', {
+          defaultMessage: 'Support for time intervals was removed',
+        });
+
+        const warningText = i18n.translate('common.ui.indexPattern.warningText', {
+          defaultMessage: 'For more information, view the ["{title}" index pattern in management]({link})',
+          values: {
+            title: indexPattern.title,
+            link: kbnUrl.getRouteHref(indexPattern, 'edit'),
+          },
+        });
+
         toastNotifications.addWarning({
-          title: 'Support for time intervals was removed',
-          text: (
-            <Fragment>
-              For more information, view the {' '}
-              <a href={kbnUrl.getRouteHref(indexPattern, 'edit')}>{indexPattern.title} index pattern</a>
-            </Fragment>
-          ),
+          title: warningTitle,
+          text: warningText,
         });
       }
     }
@@ -415,7 +424,8 @@ export function IndexPatternProvider(Private, config, Promise, confirmModalPromi
 
       // We found a duplicate but we aren't allowing override, show the warn modal
       if (!allowOverride) {
-        const confirmMessage = `An index pattern with the title '${this.title}' already exists.`;
+        const confirmMessage = i18n.translate('common.ui.indexPattern.titleExistsLabel', { values: { title: this.title },
+          defaultMessage: 'An index pattern with the title \'{title}\' already exists.' });
         try {
           await confirmModalPromise(confirmMessage, { confirmButtonText: 'Go to existing pattern' });
           return kbnUrl.redirect('/management/kibana/indices/{{id}}', { id: potentialDuplicateByTitle.id });
@@ -431,7 +441,11 @@ export function IndexPatternProvider(Private, config, Promise, confirmModalPromi
 
       // We can override and we want to prompt for confirmation
       try {
-        await confirmModalPromise(`Are you sure you want to overwrite ${this.title}?`, { confirmButtonText: 'Overwrite' });
+        await confirmModalPromise(
+          i18n.translate('common.ui.indexPattern.confirmOverwriteLabel', { values: { title: this.title },
+            defaultMessage: 'Are you sure you want to overwrite \'{title}\'?' }),
+          { confirmButtonText: i18n.translate('common.ui.indexPattern.confirmOverwriteButton', { defaultMessage: 'Overwrite' })
+          });
       } catch (err) {
         // They changed their mind
         return false;
@@ -477,7 +491,11 @@ export function IndexPatternProvider(Private, config, Promise, confirmModalPromi
                 }
 
                 if (unresolvedCollision) {
-                  toastNotifications.addDanger('Unable to write index pattern! Refresh the page to get the most up to date changes for this index pattern.'); // eslint-disable-line max-len
+                  const message = i18n.translate(
+                    'common.ui.indexPattern.unableWriteLabel',
+                    { defaultMessage: 'Unable to write index pattern! Refresh the page to get the most up to date changes for this index pattern.' } // eslint-disable-line max-len
+                  );
+                  toastNotifications.addDanger(message);
                   throw err;
                 }
 
