@@ -17,7 +17,21 @@
  * under the License.
  */
 
+export { IndexPatternSelect } from './components/index_pattern_select';
+
 export { IndexPatternsProvider } from './index_patterns';
+
 export {
   IndexPatternsApiClientProvider,
 } from './index_patterns_api_client_provider';
+
+export {
+  INDEX_PATTERN_ILLEGAL_CHARACTERS,
+  INDEX_PATTERN_ILLEGAL_CHARACTERS_VISIBLE,
+} from './constants';
+
+export {
+  ILLEGAL_CHARACTERS,
+  CONTAINS_SPACES,
+  validateIndexPattern,
+} from './validate';
