@@ -19,9 +19,7 @@
 
 import { KBN_FIELD_TYPES } from '../../../../utils/kbn_field_types';
 
-const filterableTypes = KBN_FIELD_TYPES.filter(type => type.filterable).map(
-  type => type.name
-);
+const filterableTypes = KBN_FIELD_TYPES.filter(type => type.filterable).map(type => type.name);
 
 export function isFilterable(field) {
   return filterableTypes.includes(field.type);
