@@ -17,11 +17,12 @@
  * under the License.
  */
 
-import { capitalize, isArray, isFunction } from 'lodash';
+import { capitalize, isArray, isFunction, get } from 'lodash';
 
 import chrome from '../chrome';
 import filterTemplate from '../chrome/config/filter.html';
 import intervalTemplate from '../chrome/config/interval.html';
+import { i18n } from '@kbn/i18n';
 
 export function KbnTopNavControllerProvider($compile) {
   return class KbnTopNavController {
@@ -79,18 +80,23 @@ export function KbnTopNavControllerProvider($compile) {
     toggle = (key) => { this.setCurrent(this.isCurrent(key) ? null : key); };
     click = (key) => { this.handleClick(this.getItem(key)); };
     getItem = (key) => { return this.menuItems.find(i => i.key === key); };
-    handleClick = (menuItem) => {
+    handleClick = (menuItem, event) => {
       if (menuItem.disableButton()) {
         return false;
       }
-      menuItem.run(menuItem, this);
+      // event will be undefined when method is called from click
+      menuItem.run(menuItem, this, get(event, 'target'));
     };
     // apply the defaults to individual options
     _applyOptDefault(opt = {}) {
+      const optLabel = opt.label ? opt.label : capitalize(opt.key);
       const defaultedOpt = {
-        label: capitalize(opt.key),
+        label: optLabel,
         hasFunction: !!opt.run,
-        description: opt.run ? opt.key : `Toggle ${opt.key} view`,
+        description: opt.run ? optLabel : i18n.translate('common.ui.topNav.toggleViewAriaLabel', {
+          defaultMessage: 'Toggle {optLabel} view',
+          values: { optLabel }
+        }),
         run: (item) => this.toggle(item.key),
         ...opt
       };
