@@ -19,7 +19,7 @@
 
 export { notify } from './notify';
 export { Notifier } from './notifier';
-export { getPainlessError } from './lib';
-export { fatalError, fatalErrorInternals, addFatalErrorCallback } from './fatal_error';
-export { GlobalToastList, toastNotifications } from './toasts';
+export { fatalError, addFatalErrorCallback } from './fatal_error';
+export { toastNotifications } from './toasts';
 export { GlobalBannerList, banners } from './banners';
+export { addAppRedirectMessageToUrl, showAppRedirectNotification } from './app_redirect';
