@@ -36,24 +36,3 @@ export const formatESMsg = (err) => {
   const result = _.pluck(rootCause, 'reason').join('\n');
   return result;
 };
-
-export const getPainlessError = (err) => {
-  const rootCause = getRootCause(err);
-
-  if (!rootCause) {
-    return;
-  }
-
-  const { lang, script } = rootCause[0];
-
-  if (lang !== 'painless') {
-    return;
-  }
-
-  return {
-    lang,
-    script,
-    message: `Error with Painless scripted field '${script}'`,
-    error: err.message,
-  };
-};
