@@ -17,6 +17,7 @@
  * under the License.
  */
 
-export { formatESMsg, getPainlessError } from './format_es_msg';
+export { formatESMsg } from './format_es_msg';
 export { formatMsg } from './format_msg';
 export { formatStack } from './format_stack';
+export { isAngularHttpError, formatAngularHttpError } from './format_angular_http_error';
