@@ -16,6 +16,4 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
-export { GlobalToastList } from './global_toast_list';
-export { toastNotifications } from './toast_notifications';
+export { toastNotifications, __newPlatformInit__ } from './toasts';
