@@ -1,9 +1,28 @@
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 import _ from 'lodash';
-import { uiModules } from 'ui/modules';
+import { uiModules } from '../modules';
 
 const module = uiModules.get('kibana');
 
-// Provides a tiny subset of the excelent API from
+// Provides a tiny subset of the excellent API from
 // bluebird, reimplemented using the $q service
 module.service('Promise', function ($q, $timeout) {
   function Promise(fn) {
@@ -76,7 +95,7 @@ module.service('Promise', function ($q, $timeout) {
 
     let value;
 
-    if (_.isArray(args)) {
+    if (Array.isArray(args)) {
       try { value = fn.apply(ctx, args); }
       catch (e) { return Promise.reject(e); }
     } else {
@@ -105,71 +124,3 @@ module.service('Promise', function ($q, $timeout) {
 
   return Promise;
 });
-
-module.factory('PromiseEmitter', function (Promise) {
-  /**
-   * Create a function that uses an "event" like pattern for promises.
-   *
-   * When a single argument is passed, this will behave just like calling `new Promise(fn)`,
-   * but when a second arguemnt is passed, the fn will be used to recreate a promise eveytime
-   * the previous is resolved. The following example demonstrates what this allows:
-   *
-   * When using `new Promise()` to create a promise, you can allow consumers to be
-   * notified of a single change:
-   * ```
-   * obj.onUpdate= function() {
-   *   // NOTE: we are NOT using `new Promise.emitter()` here
-   *   return new Promise(function (resolve, reject) {
-   *     // wait for the update...
-   *     resolve();
-   *   });
-   * }
-   * ```
-   *
-   * And the consumer can ask for continual updates be re-invoking the `.onChange()` method
-   * every time a change occurs:
-   * ```
-   * obj.onChange().then(function useChanges(change) {
-   *   // use changes...
-   *   // then register to receive notifcation of the next change
-   *   obj.onChange().then(useChanges);
-   * });
-   * ```
-   *
-   * But by defining obj.onChange using `new Promise.emitter`:
-   * ```
-   * obj.onChange = function (handler) {
-   *   return new Promise.emitter(function (resolve, reject) {
-   *     // wait for changes...
-   *     resolve();
-   *   });
-   * };
-   * ```
-   *
-   * The consumer can now simplify their code by passing the handler directly to `.onUpdate()`
-   * and the boilerplate of recalling `.onUpdate()` will be handled for them.
-   * ```
-   * obj.onChanges(function useChanges(changes) {
-   *   // use changes...
-   * });
-   * ```
-   *
-   * @param  {Function} fn - Used to init the promise, and call either
-   *                       reject or resolve (passed as args)
-   * @param  {Function} handler - A function that will be called every
-   *                            time this promise is resolved
-   *
-   * @return {Promise}
-   */
-  function PromiseEmitter(fn, handler) {
-    const prom = new Promise(fn);
-
-    if (!handler) return prom;
-
-    return prom.then(handler).then(function recurse() {
-      return new PromiseEmitter(fn, handler);
-    });
-  }
-
-  return PromiseEmitter;
-});
