@@ -16,5 +16,4 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
-import './directive/query_bar';
+export { QueryBar } from './components';
