@@ -1,10 +1,30 @@
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 import { cloneDeep, defaultsDeep, wrap } from 'lodash';
 
 import { wrapRouteWithPrep } from './wrap_route_with_prep';
 import { RouteSetupManager } from './route_setup_manager';
 import { parsePathToBreadcrumbs } from './breadcrumbs';
 
-function RouteManager() {
+// eslint-disable-next-line @elastic/kibana-custom/no-default-export
+export default function RouteManager() {
   const self = this;
   const setup = new RouteSetupManager();
   const when = [];
@@ -81,5 +101,3 @@ function RouteManager() {
 
   self.RouteManager = RouteManager;
 }
-
-module.exports = RouteManager;
