@@ -16,12 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 import { mapValues } from 'lodash';
-
+/**
+ * Takes in a parsed url query and state objects, finding the state objects that match the query parameters and expanding
+ * the hashed state. For example, a url query string like '?_a=@12353&_g=@19028df' will become
+ * '?_a=[expanded app state here]&_g=[expanded global state here]. This is used when storeStateInSessionStorage is turned on.
+ */
 export function unhashQueryString(parsedQueryString, states) {
-  return mapValues(parsedQueryString, (val, key) => {
-    const state = states.find(s => key === s.getQueryParamName());
-    return state ? state.translateHashToRison(val) : val;
-  });
+    return mapValues(parsedQueryString, function (val, key) {
+        var state = states.find(function (s) { return key === s.getQueryParamName(); });
+        return state ? state.translateHashToRison(val) : val;
+    });
 }
