@@ -1,3 +1,22 @@
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 import {
   parse as parseUrl,
   format as formatUrl,
@@ -9,9 +28,9 @@ import {
   stringify as stringifyQueryString
 } from 'querystring';
 
-import unhashQueryString from './unhash_query_string';
+import { unhashQueryString } from './unhash_query_string';
 
-export default function unhashUrl(urlWithHashes, states) {
+export function unhashUrl(urlWithHashes, states) {
   if (!urlWithHashes) return urlWithHashes;
 
   const urlWithHashesParsed = parseUrl(urlWithHashes, true);
