@@ -16,15 +16,17 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
-export class StringUtils {
-
-  /**
-   * Returns a version of the string with the first letter capitalized.
-   * @param str {string}
-   * @returns {string}
-   */
-  static upperFirst(str) {
-    return str ? str.charAt(0).toUpperCase() + str.slice(1) : '';
-  }
-}
+var StringUtils = /** @class */ (function () {
+    function StringUtils() {
+    }
+    /**
+     * Returns a version of the string with the first letter capitalized.
+     * @param str {string}
+     * @returns {string}
+     */
+    StringUtils.upperFirst = function (str) {
+        return str ? str.charAt(0).toUpperCase() + str.slice(1) : '';
+    };
+    return StringUtils;
+}());
+export { StringUtils };
