@@ -17,5 +17,11 @@
  * under the License.
  */
 
-export const defaultFeedbackMessage = `Have feedback? Please create an issue in
-<a href="https://github.com/elastic/kibana/issues/new" rel="noopener noreferrer" target="_blank">GitHub</a>.`;
+import { i18n } from '@kbn/i18n';
+
+export const defaultFeedbackMessage = i18n.translate('common.ui.vis.defaultFeedbackMessage',
+  {
+    defaultMessage: 'Have feedback? Please create an issue in {link}.',
+    values: { link: '<a href="https://github.com/elastic/kibana/issues/new" rel="noopener noreferrer" target="_blank">GitHub</a>' }
+  }
+);
