@@ -25,6 +25,9 @@ const colormaps = vislibColorMaps;
 for (const key in colormaps) {
   if (colormaps.hasOwnProperty(key)) {
     //slice off lightest colors
-    truncatedColorMaps[key] = colormaps[key].slice(Math.floor(colormaps[key].length / 4));
+    truncatedColorMaps[key] = {
+      ...colormaps[key],
+      value: colormaps[key].value.slice(Math.floor(colormaps[key].value.length / 4))
+    };
   }
 }
