@@ -1,6 +1,26 @@
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 import _ from 'lodash';
-import VislibComponentsZeroInjectionFlattenDataProvider from './flatten_data';
-export default function UniqueXValuesUtilService(Private) {
+import { VislibComponentsZeroInjectionFlattenDataProvider } from './flatten_data';
+
+export function VislibComponentsZeroInjectionUniqKeysProvider(Private) {
 
   const flattenDataArray = Private(VislibComponentsZeroInjectionFlattenDataProvider);
 
@@ -38,9 +58,6 @@ export default function UniqueXValuesUtilService(Private) {
       const key = d.x;
       const prev = uniqueXValues.get(key);
       let sum = d.y;
-      if (d.xi != null) {
-        i = d.xi;
-      }
 
       if (prev) {
         i = Math.min(i, prev.index);
@@ -58,4 +75,4 @@ export default function UniqueXValuesUtilService(Private) {
 
     return uniqueXValues;
   };
-};
+}
